typesystem Package
==================

:mod:`typesystem` Package
-------------------------

.. automodule:: numba.typesystem
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`closuretypes` Module
--------------------------

.. automodule:: numba.typesystem.closuretypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`constants` Module
-----------------------

.. automodule:: numba.typesystem.constants
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ctypestypes` Module
-------------------------

.. automodule:: numba.typesystem.ctypestypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`defaults` Module
----------------------

.. automodule:: numba.typesystem.defaults
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`itypesystem` Module
-------------------------

.. automodule:: numba.typesystem.itypesystem
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`kinds` Module
-------------------

.. automodule:: numba.typesystem.kinds
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`llvmtypes` Module
-----------------------

.. automodule:: numba.typesystem.llvmtypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lowering` Module
----------------------

.. automodule:: numba.typesystem.lowering
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numbatypes` Module
------------------------

.. automodule:: numba.typesystem.numbatypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numpy_support` Module
---------------------------

.. automodule:: numba.typesystem.numpy_support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`promotion` Module
-----------------------

.. automodule:: numba.typesystem.promotion
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ssatypes` Module
----------------------

.. automodule:: numba.typesystem.ssatypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tbaa` Module
------------------

.. automodule:: numba.typesystem.tbaa
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`templatetypes` Module
---------------------------

.. automodule:: numba.typesystem.templatetypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typematch` Module
-----------------------

.. automodule:: numba.typesystem.typematch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`types` Module
-------------------

.. automodule:: numba.typesystem.types
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typeset` Module
---------------------

.. automodule:: numba.typesystem.typeset
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typeutils` Module
-----------------------

.. automodule:: numba.typesystem.typeutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`universe` Module
----------------------

.. automodule:: numba.typesystem.universe
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.typesystem.tests

